@@ -4,13 +4,15 @@ use strict;
 use warnings;
 use diagnostics;
 
+# ABSTRACT: Data store to support Net::LDAP::SimpleServer
+
+our $VERSION = '0.0.13';    # VERSION
+
 use Carp;
 use UNIVERSAL::isa;
 use Scalar::Util qw(blessed reftype);
 use Net::LDAP::LDIF;
 
-use version; our $VERSION = qv('0.0.12');
-
 sub new {
     my ( $class, $param ) = @_;
     my $self = bless( { list => undef }, $class );
@@ -29,6 +31,7 @@ sub load {
 
     $self->{ldifobj} = _open_ldif($param);
     $self->{list}    = _load_ldif( $self->{ldifobj} );
+    return;
 }
 
 sub ldif {
@@ -103,11 +106,20 @@ sub filter {
 }
 
 1;    # Magic true value required at end of module
-__END__
+
+
+
+=pod
+
+=encoding utf-8
 
 =head1 NAME
 
-Net::LDAP::SimpleServer::LDIFStore - Data store to support C<Net::LDAP::SimpleServer>
+Net::LDAP::SimpleServer::LDIFStore - Data store to support Net::LDAP::SimpleServer
+
+=head1 VERSION
+
+version 0.0.13
 
 =head1 SYNOPSIS
 
@@ -135,13 +147,13 @@ LDIF file where the data is stored.
 As of now, this interface is quite simple, and so is the underlying data
 structure, but this can be easily improved in the future.
 
-=head1 CONSTRUCTOR 
+=head1 CONSTRUCTOR
 
 =over
 
 =item new()
 
-Creates a store with no data in it. It cannot be really used like that, you 
+Creates a store with no data in it. It cannot be really used like that, you
 B<must> C<< load() >> some data in it first.
 
 =item new( FILE )
@@ -211,7 +223,7 @@ C<true>.
     files, and the meaning of any environment variables or properties
     that can be set. These descriptions must also include details of any
     configuration language used.
-  
+
 Net::LDAP::SimpleServer requires no configuration files or environment variables.
 
 =head1 DEPENDENCIES
@@ -228,47 +240,64 @@ None reported.
 
 =head1 BUGS AND LIMITATIONS
 
-This store does not yet support writing to a LDIF file, which makes the 
+This store does not yet support writing to a LDIF file, which makes the
 C<< Net::LDAP::SimpleServer >> a read-only server.
 
-No bugs have been reported.
+=head1 SEE ALSO
 
-Please report any bugs or feature requests to
-C<bug-net-ldap-simpleserver@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Net::LDAP::SimpleServer|Net::LDAP::SimpleServer>
+
+=back
 
 =head1 AUTHOR
 
-Alexei Znamensky  C<< <russoz@cpan.org> >>
+Alexei Znamensky <russoz@cpan.org>
 
-=head1 LICENCE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2010, Alexei Znamensky C<< <russoz@cpan.org> >>. All rights reserved.
+This software is copyright (c) 2011 by Alexei Znamensky.
 
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org>.
 
 =head1 DISCLAIMER OF WARRANTY
 
 BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
+WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
+PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
+EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
+SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
+THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
 
 IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
 WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
+TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
+SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
 RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
 FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
+DAMAGES.
+
+=cut
+
+
+__END__
 
